@@ -13,10 +13,11 @@ function(x) {
             stop("qvalue needed for this to work. Please install it.",
                       call. = FALSE)
                       }                   
-                fdr.adj<-try(qvalue::qvalue(x$results$gc.p.value),silent=TRUE)
-             if(class(fdr.adj)=="try-error") {
-                fdr.adj <- try(qvalue::qvalue(x$results$gc.p.value, pi0.method = "bootstrap"),silent=TRUE)
-                if(class(fdr.adj)=="try-error") {
+                fdr.adj<-tryCatch(qvalue::qvalue(x$results$gc.p.value), error = function(e) NULL)
+             if(is.null(fdr.adj)) {
+                fdr.adj <- tryCatch(qvalue::qvalue(x$results$gc.p.value, pi0.method = "bootstrap"), 
+                                      error = function(e) NULL)
+                if(is.null(fdr.adj)) {
                   fdr.method="BH"
                 }}}
             if(fdr.method!="qvalue") {
